bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 26. Aventiure
___________________________________________________ #### abentewer wy sy mit Elsen vnd Gelpfraten striten vnd #### wye in gelang
| ### <Do> sy nu wol gesunt kamen auff den sant ### der künig begonde fragen wer schol vns durch daz lant ### dy rechten weg weisen daz wir nicht vervaren ### do sprach der kün Volcker daz schol ich ein wol bewarn–
###### 1627 | ### Nu enthaltet euch sprach Hagen ritter vnd knecht ### vnd engahet nicht ze sere daz düncket mich recht ### vil vngefüge mär tun ich euch bekant ### wir kumen nymmer heym in vnser lant
###### 1628 | ### Daz sagten mir tzwey mer weip hewt morgen fru ### wir enkemen nymmer wider nu rat ich waz man tu ### daz ir euch waffent helde vnd zu streit euch wol bewart ### wir haben hy starcke veind daz ir gewerlichen vart
###### 1629 | ### Ich wande an lugen funde dy waßer <weisen> weip ### sy iahen daz besunder daz vnser keines leip ### wider ze land kem newr der capplan ### darümb ich in [107v]gern hewt ertrenckt wolt han
###### 1630 | ### Da flugen dise mer von scharen baz zu scharen ### des wurden snell beld vor leid missvar ### do sy begonden sorgen auff den grimmigen tot ### an der hoff reys des ging sy werlichen not
###### 1631 | ### Da ze Moringe si waren über kumen ### do dem Else vergen was der leip benomen ### do sprach aber Hagen seint daz ich [58r] vinde han ### an dirre vart erworben wir werden sicherlich bestan
###### 1632 | ### Ich slvoch der herren vergen hivte morgen frvo ### si wizen wol div mære nv grifet balde zvo ### ob Else vn– Gelpfrat noch hivte hie bestat ### vnser ingesinde daz ez in schedelich erge
###### 1633 | ### Ich erchenne si so chvene ez wirdet niht verlan ### div ros div svlt ir lazen deste sanfter gan ### daz des iemen wæne wir vliehen vf den wegen ### des rates svln wir volgen sprach da vil maniger chvner degen
| ### Wer sol nv daz gesinde wisen vber lant ### si sprachen daz tvo Volker dem sint hie wol bechant ### stige vn– straze der chune spileman ### ê daz manz gespræche do sah man wol gewafent stan
###### 1635 | ### den snellen videlære den helm er vf gebant ### in herlicher varwe was al sin wichgewant ### er bant ovch zeime <scafte> ein zeichen daz was rot ### sit chom er mit den chvnigen in eine grozliche not
###### 1636 | ### Do was tot des vergen nv Gelpfrate chomen ### mit eime waren mære do het iz ovch vernomen ### sin brvoder Else ez was in beiden leit ### si sanden nach ir degenen die waren schiere bereit
###### 1637 | ### In vil churcen citen als wir vernomen han ### sah man zv zin riten die heten scaden getan ### in starchem vrlivge vil vngefvgiv ser ### der chomen Gelpfrate wol siben hundert oder mer
###### 1638 | ### Do si ir grimmen vinden begunden riten nach ### ia leiten si ir herren den was ein teil ze gach ### nach den chvenen gesten si wolden anden zorn ### des wart der herren frivnde sider mere verlorn
| ### Do het der wise Hagene wol gefvget daz ### wie mohte siner frivnde ein helt gehuten baz ### er pflac der nachhvote mit sehzech siner man ### vn– Danchwart siner brvder daz was vil wislich getan
###### 1640 | ### In was des tages zervnnen des heten si niht mer ### er vorht an sinen frivnden leit vn– ser ### si riten vnder schilden durch der Beyer lant ### dar nach in churcen stvnden die helde wrden an gerant
###### 1641 | ### Beidenthalp der strazen vn– hinden vaste nnach ### hvofslege si horten dem volche was ze gach ### do sprach der chvne Danchwart man wil hie vns bestan ### nv binden vf die helme daz ist ratlich getan
###### 1642 | ### Si hielten ab ir verte als ez do mvose sin ### si sahen in der vinster der liehten helme schin ### done wolde Hagene niht lamger si verdagen ### wer iagt vns vf der straze daz mvos im Gelpfrat do sagen
| ### Do sprach der marcgrave vzer Beyerlant ### wir haben vnsern vinden da her nach gerant ### ine weiz niht wer mir hvte minen vergen slvoc ### der was ein helt zen handenn daz ist mir leide genvoc
###### 1644 | ### Do sprach von Tronege Hagene was der verge din ### der enwolde uns niht fvren [58v]des ist div schulde min ### do slvog ich dinen vergen deiswar des gie mir not ### ich hete von dem degene vil nach gewnnen den tot
###### 1645 | ### Ich bot im mine miete golt silber vn– gewant ### daz er vns vber fvrte her in iwer lant ### daz mvte in harte sere in zorne er mich do slvoc ### mit einer starchen schalten vil wenic ich im do vertrvoc
###### 1646 | ### Do kom ich zvo dem swerte vn– wert im sinen zorn ### mit einer starchen wnden des wart der helt verlorn ### daz bringe ich <iv> ze svone swie ivch nv dvnchet gvot ### do giengez an ein striten si wrden zornic gemvot
| ### Ich wistez wol <sprach> Gelpfrat do hie fver gereit ### Gvnther mit den sinen daz vns geschêhe leit ### von Hagen vbermvete nv ensol er niht genesen ### fvr des vergen ende sol er pfant hie wesen
###### 1648 | ### Si neigten vber schilde ze stiche div starchen sper ### Gelpfrat vn– Hagene in was zein ander ger ### Else vn– Danchwart ovch zesamne riten ### in vil hohem mvote da wart grimme do gestriten
###### 1649 | ### Wie chunden sich versvchen immer helde baz ### von eime starchen schafte hinder ors gesaz ### Hagene der chvene vor Gelpfrates hant ### im brast daz fverbvege do wart im vallen bechant
###### 1650 | ### Uon ir ingesinde der chrach der schefte schal ### do erholt ovch sich dort Hagene der ê des was zetal ### chomen von der tioste nider an daz gras ### er wæn vnsænftes mvtes wider Gelpfrate was
| ### Wer in div ros behielte daz ist mir vnbechant ### si warn von den sætelen chomen vf den sant ### Gelpfrate vn– Hagene ein ander liefen an ### des hvlfen ir gesellen da wart striten getan
###### 1652 | ### Swie chreftechlichen Hagene zvo Gelpfrate spranch ### der edel marcgrave des schiltes hin im swanch ### wol gegen einer ellen daz fivre dræte dan ### des was vil nach erstorben des kunich Gunthers man
###### 1653 | ### Do begunder rvefen Danchwarten an ### hilfa lieber brvoder ia hat mich bestan ### ein rehter helt zen handen ern læt mich niht genesn ### do sprach der chvene Danchwart des schol ich scheidere wesn
###### 1654 | ### Do spranger dar vil balde vn– slvg im einen slac ### da von der herre Gelpfrat vor im got gelac ### Else wolde gerne rechen do den man ### sit mvser schedeliche mit den sinen cheren dan
###### 1655 | ### Im was erslagen der brvoder selbe was er wnt ### wol ahzech siner degene beliben an der stvnt ### mit dem vil grimme tode Else mvse dan ### flvhtechliche wenden daz heten geste getan
###### 1656 | ### Do die von Bayerlanden wichen vf dem wege ### do horte man noch hellen die vreislichen slege ### do iageten die von Tronege ir vianden nach ### die ez niht engelten wanden den was allen ze gach
###### 1657 | ### Do sprach an ir vlvehte Danch[110r Z 10]wart der degen ### wir schüllen widerkern– balde auff disen wegen ### vnd laß wir sy reiten sy sint von blute naz ### gahen wir zu den frewndn– an trewn– rat ich daz
###### 1658 | ### Do sy hin wider kamen do der streit was geschehen ### do sprach der kün Hagen helt ir schüllt besehen ### wes vns hy geprest oder wen wir haben verlorn– ### in disem herten streite durch disen Gelpfrades tzorn–
###### 1659 | ### Sy hetten verlorn– vir daz lißen sy also sein ### ez was wol vergoltn– mit wunden vnter in ### den von Baierlanden [110v]sy hundert lißen tod ### des waren den von Trongen ir schild trüb vnd rot
###### 1660 | ### Ein teil schein auß den wolcken des lichten manen brehen ### do sprach aber Hagen nymant schol veriehen ### dem meinen liben herren daz wir hy haben getan ### man schol sy an sorgen vntz morgen reiten <lan>
###### 1661 | ### Do sy da nach in kamen dy dort da striten ee ### da tet dem ingesind dy müde starcke we ### wy lang schüll wir reiten des fraget manich man ### do sprach der kün Danckwart wir mügen nicht herwerg gehan
###### 1662 | ### Ir müßt alle reiten vntz daz ez werd tag ### Volcker der kün der der phan– pfhlag ### bat den marschalck vragen wo schüll wir heint sein ### da geru vnser mere vnd auch dy liben herrn– mein
###### 1663 | ### Do sprach der kün Danckwart ich kan euch ez nicht gesagen ### wir mügen nicht geruen e ez beginnet tagen ### wo wir ez dann finden so ligen in einem gras ### do sy daz vernamen wy leid [111r]in etlichen was
###### 1664 | ### Si bliben vnuermailet des heißen blutes rot ### vntz daz dy sun– ir lichtez scheinen bot ### den morgen über berge do daz der künig gesach ### daz sy gestriten hetten der künig vil tzörnicklichn– sprach
###### 1665 | ### Wy nu frewnt Hagen ich waen versmaht daz ### daz ich bey euch wäre daz euch dy ringe naz ### sust wurden von dem blute wer hat euch daz getan ### er sprach daz tet Gelpfrat der hett vns nahen bestan
###### 1666 | ### Durch den seinen vergen wir wurden angerant ### do slug Gelpfrads meines bruder hant ### seint entran vns Else des twang in michel not ### yn hundert vnd vns vir bliben in dem streite tot
###### 1667 | ### Wir enkonden nicht bescheiden war sy sich legten nider ### all dy lantlewt erfunden ez wol sider ### daz ze bof füren der edeln– Vtten kint ### sy wurden wol enpfangn– da ze Paßaw sint
###### 1668 | ### Der <edeln–> fürsten öhem bischoff Pilgrem ### dem ward vil wol zu mute do er dy neuen sein ### sab mit so vil der recken kumen in daz [111v]lant ### daz er sy gern säh daz ward im schir bekant
###### 1669 | ### Sy wurden wol enpfangen von frewnden auff den wegen ### da zu Paßaw kond er sy nicht gelegen ### sy musten über daz waßer da sy funden velt ### da slugen auff dy knechte manig hut vnd getzelt
###### 1670 | ### Sy musten da bleiben allen einen tag ### vnd auch dy nacht mit vollen wy schon man ir pfhlag ### darnach sy musten reiten in Rüdigers lant ### dem kamen auch dy mere daz was in libe bekant
###### 1671 | ### Do dy wege müden rue genamen ### vnd sy dem lande naher bekamen ### sy funden auff der vart slaffend einen man ### dem von Trong Hagen sein starckez waffen an gewan
###### 1672 | ### Eckhart was geheißen der selb ritter gut ### er gewan darümb vil trawrigen mut ### daz er verlos sein waffen von der helde vart ### dy march Rüdigers fundens übel bewart
###### 1673 | ### Awe mir diser schaden sprach do Eckhart ### ja rewet mich sere der Burgunden vart ### sint ichs in friden verlos do was mein frewd ergan [112r] ### awe herr Rüdiger wy ich wider dich geworben han
###### 1674 | ### Hagen vil wol hort sein clagen sorg im klagen gepot ### er gab im wider sein wappen vnd sechs pouche rot ### dy hab dir helt ze minnen daz du mein frewnt seyst ### du bist ein degen küne wy ein du auff der march seist
###### 1675 | ### Got lan euch ewer gabe sprach da Eckgewart ### doch rewet mich vil sere zu den Hewnen ewer vart ### ir sluget Seifriden man ist euch gehaz ### daz ir euch wol behütet in trewen rate ich euch daz
###### 1676 | ### Nu müß vns got behüten sprach do Hagen ### wir haben an disen tzeiten nicht mer ze tragen ### nur wo mein hern noch heinte mügen han ### nachtseld in disem lande da sy geruen vnd ir man
###### 1677 | ### Dy ros sind vns <vermüdet> auff den verren wegen ### vnd der speis zerinnen sprach Hagen der degen ### wir findens nindert feyl vns wär wirtes not ### der vns noch heinte geb durch sein mild sein brot
###### 1678 | ### Des antwort im da Eckhart ich tzeig euch einen wirt ### daz ir ze haws [112v]selten so wol bekomen pirt ### in keinem frömden lande als euch wol mag geschehen ### ob ir vil snelle degen wöllet Rüdigern– sehen
###### 1679 | ### Der sitzet bey der strazz vnd ist der beste wirt ### der y kam ze haws sein hertz tugent birt ### als der lichte meye daz gras mit blumen tut ### so er schol helden dienen so ist er frölich gemut
###### 1680 | ### Do sprach der künig Günthher wöllt ir mein bot sein ### ob vns wöll enthalten durch den willen mein ### der markegraff Rüdiger vnser mag vnd vnser man ### daz wil ich ymmer dinen mit trewen so ich beste kan
###### 1681 | ### Der bot pin ich gern– sprach da Eckgewart ### in vil gutem willen hub er sich an dy vart ### vnd sagte Rüdiger wen er hett gesehen ### vnd auch Götlinde do was in lib geschehen
###### 1682 | ### Man sah ze Bechlarn gahen einen degen ### selb erkant in Rüdiger er sprach auff disen wegen ### dort her gahet Eckewart ein Crimhilden [59r]man ### er wande daz die viende im heten etewaz getan
###### 1683 | ### Do gie er fvr die porte da er den boten vant ### daz swert er von im gvrte vn– leit ez von der hant ### er sprach zv dem degene waz habt ir vernomen ### daz ir also sere hat vns iemen iht genomen
| ### Vns hat geschadet niemen sprach Eckewart zehant ### mich habent dri kunige her zvo ziv gesant ### Gunther von Burgonden Giselher vn– Gernot ### der rechen ieslicher iv sinen dienest her enbot
###### 1685 | ### Daz selbe tvot her Hagene vn– ovch Volker ### ir dienest willechliche noch sage ich iv mer ### daz iv des kuniges marschalch Dancwart daz enbot ### daz den gvten degenen wêr iwer herberge not
###### 1686 | ### Mit lachendem munde sprach do Rvdeger ### nv wol mich dirre mære daz die kunige her ### miner herberge rvochent div wirt in niht verseit ### choement si mir ze hvose mit dienste bin ich in bereit
###### 1687 | ### Ivch hat des kuniges <marschalch> heizen wizzen lan ### wen ir ze herbergen noch hinte mvzet han ### sehzech chuoner rechen vn– tvsent ritter gvot ### vn– nivn tvsent knehte do wart er vroelich gemvot
###### 1688 | ### So wol mich dirre geste sprach do Rvdeger ### daz mir choment ze hvose die rechen also her ### den ich noch vil selten iht gedienet han ### nv riten in begegene mine mage vn– man
###### 1689 | ### Uon gahen zv den rossen hvop sich da michel not ### von rittern vn– von knehten der wirt do gebot ### den sinen ambtlvten si schvffenz deste baz ### noch <enwistes> niht frov Gotelint div in ir kemenaten saz
| ### Do gie der marcgrave da er die frowen vant ### sine wip vn– sine tohter do sagter in zehant ### div vil lieben mære div er hete vernomen ### daz ir frowen brvder ir ze hvse solden chomen
###### 1691 | ### Vil liebiv trvtinne sprach do Rvdeger ### ir svlt vil wol enpfahen die edeln kunige her ### so si mit ir gesinde fvr ivch ze hove gan ### ir svlt oech schone grvzen Hagenen Guntheres man
###### 1692 | ### Mit in chvmt ovch einer der heizet Dancwart ### der ander heizet Volker an zvhten wol bewart ### die sehse svlt ir chussen ir vnt div tohter min ### vn– svlt ovch bi den degenen inzvehten groezliche sin
###### 1693 | ### Daz lobten do die frowen vn– warens vil bereit ### si svhten vz den kisten div maniger <handen> chleit ### dar inne si begegene den rechen wolden gan ### da wart vil michel vlizen von schonen frowen getan

<<< Übersicht <<< vorige Seite nächste Seite >>>